# Free Draw Diagrams
### On this page
  * [Creating Free Draw Diagrams](https://help.sap.com/docs/leanix/ea/free-draw?version=CLOUD#creating-free-draw-diagrams)
  * [Using Free Draw Diagrams](https://help.sap.com/docs/leanix/ea/free-draw?version=CLOUD#using-free-draw-diagrams)
  * [Adding Fact Sheets as Shapes](https://help.sap.com/docs/leanix/ea/free-draw?version=CLOUD#adding-fact-sheets-as-shapes)
  * [Linking and Unlinking Fact Sheets to Shapes](https://help.sap.com/docs/leanix/ea/free-draw?version=CLOUD#linking-and-unlinking-fact-sheets-to-shapes)
  * [Changing and Opening Linked Fact Sheets](https://help.sap.com/docs/leanix/ea/free-draw?version=CLOUD#changing-and-opening-linked-fact-sheets)
  * [Creating New Fact Sheets and Relations from Within the Canvas](https://help.sap.com/docs/leanix/ea/free-draw?version=CLOUD#creating-new-fact-sheets-and-relations-from-within-the-canvas)
  * [Types of Connections Between Fact Sheets](https://help.sap.com/docs/leanix/ea/free-draw?version=CLOUD#types-of-connections-between-fact-sheets)
  * [Expanding Interfaces](https://help.sap.com/docs/leanix/ea/free-draw?version=CLOUD#expanding-interfaces)


View all
SAP LeanIX Free Draw enables you to create custom diagrams and visual representations of their enterprise architecture. It offers the flexibility to design diagrams from scratch using different shapes, symbols, and connectors.
Free Draw diagrams allow you to visualize and explore dependencies among various architectural elements. You can create custom visualizations, such as organizational hierarchies and business capability maps, to provide a tailored view of the architecture. It enables you to dive deep into specific architectural elements, conduct detailed investigations by zooming in on specific areas, and explore relationships and dependencies with focus. In the section "Using diagrams for assessment", you will gain further insight into how diagrams can be utilized for evaluating architecture.
